@@ -47,19 +47,19 @@ def create_training_job(local_data, source_code, weights, hyper_param):
         __upload_one_folder(job_id, FileType.Traindata.name, local_data)
         print(f"uploaded {local_data}")
     else:
-        print("local_data already exists")
+        print(f"local_data already exists")
 
     if source_code is not None:
         __upload_one_file(job_id, FileType.Code.name, source_code)
         print(f"uploaded {source_code}")
     else:
-        print("source_code already exists")
+        print(f"source_code already exists")
 
     if weights is not None:
         __upload_one_file(job_id, FileType.Weights.name, weights)
         print(f"uploaded {weights}")
     else:
-        print("weights already exists")
+        print(f"weights already exists")
 
     # put hyper param to Dynamodb through API Gateway
     headers = {
